@@ -1,3 +1,3 @@
 ''' A tiny secret manager written in python'''
-__version__ = "0.0.2"
-from .secret import *
+__version__="0.0.2"
+from .secretm import *
